==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/et_EE.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Samm 1 ebaõnnestus. Erind: %s",
    "Step 2 failed. Exception: %s" : "Samm 2 ebaõnnestus. Erind: %s",
    "External storage" : "Väline andmehoidla",
    "Personal" : "Isiklik",
    "System" : "Süsteem",
    "Grant access" : "Anna ligipääs",
    "Error configuring OAuth1" : "OAuth1 seadistamise tõrge",
    "Error configuring OAuth2" : "OAuth2 seadistamise tõrge",
    "Generate keys" : "Loo võtmed",
    "Error generating key pair" : "Viga võtmepaari loomisel",
    "All users. Type to select user or group." : "Kõik kasutajad. Kirjuta, et valida kasutaja või grupp.",
    "(group)" : "(grupp)",
    "Admin defined" : "Admini poolt määratud",
    "Saved" : "Salvestatud",
    "Save" : "Salvesta",
    "Empty response from the server" : "Tühi vastus serverilt",
    "Couldn't get the list of external mount points: {type}" : "Välise ühenduspunkti hankimine ebaõnnestus: {type}",
    "There was an error with message: " : "Sõnumiga tekkis tõrge:",
    "External mount error" : "Välise seostamise tõrge",
    "external-storage" : "väline-salvestuskoht",
    "Username" : "Kasutajanimi",
    "Password" : "Parool",
    "Credentials required" : "Kasutajatunnused on nõutud",
    "Storage with id \"%i\" not found" : "Salvestuskohta ID-ga \"%i\" ei leitud",
    "Invalid mount point" : "Vigane ühenduspunkt",
    "Objectstore forbidden" : "Objectstore on keelatud",
    "Invalid storage backend \"%s\"" : "Vigane salvestuskoha taustsüsteem \"%s\"",
    "Unsatisfied backend parameters" : "Rahuldamata taustarakenduse parameetrid",
    "Insufficient data: %s" : "Pole piisavalt andmeid: %s",
    "%s" : "%s",
    "Access key" : "Ligipääsuvõti",
    "Secret key" : "Salavõti",
    "Builtin" : "Sisseehitatud",
    "None" : "Pole",
    "OAuth1" : "OAuth1",
    "App key" : "Rakenduse võti",
    "App secret" : "Rakenduse salasõna",
    "OAuth2" : "OAuth2",
    "Client ID" : "Kliendi ID",
    "Client secret" : "Kliendi salasõna",
    "OpenStack" : "OpenStack",
    "API key" : "API võti",
    "RSA public key" : "RSA avalik võti",
    "Public key" : "Avalik võti",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Korv",
    "Hostname" : "Hostinimi",
    "Port" : "Port",
    "Region" : "Piirkond",
    "Enable SSL" : "SSL-i kasutamine",
    "Enable Path Style" : "Luba otsingtee stiilis",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Mujahl olev alamkaust",
    "Secure https://" : "Turvaline https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Turvaline ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Kohalik",
    "Location" : "Asukoht",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Juur",
    "SFTP with secret key login" : "SFTP koos salajase võtmega logimisega",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Jaga",
    "Domain" : "Domeen",
    "SMB / CIFS using OC login" : "SMB / CIFS kasutades OC logimist",
    "Username as share" : "Kasutajanimi kui jagamine",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Teenuse nimi",
    "<b>Note:</b> " : "<b>Märkus:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Märkus:</b> cURL tugi puudub PHP paigalduses. FTP %s hoidla ühendamine pole võimalik. Palu oma süsteemihalduril paigaldata cURL tugi.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Märkus:</b> FTP tugi puudub PHP paigalduses. FTP %s hoidla ühendamine pole võimalik. Palu oma süsteemihalduril paigaldata FTP tugi.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Märkus:</b> \"%s\" pole paigaldatud. Hoidla %s ühendamine pole võimalik. Palu oma süsteemihalduril paigaldata vajalik tugi.",
    "No external storage configured" : "Välist salvestuskohta pole seadistatud",
    "You can add external storages in the personal settings" : "Sa võid lisada välise salvestuskoha isiklikes seadetes",
    "Name" : "Nimi",
    "Storage type" : "Andmehoidla tüüp",
    "Scope" : "Skoop",
    "Enable encryption" : "Luba krüpteerimine",
    "Enable previews" : "Luba eelvaated",
    "Enable sharing" : "Luba jagamine",
    "Check for changes" : "Otsi uuendusi",
    "Never" : "Mitte kunagi",
    "Once every direct access" : "Kord iga otsese pöördumise korral",
    "External Storage" : "Väline salvestuskoht",
    "Folder name" : "Kausta nimi",
    "Authentication" : "Autentimine",
    "Configuration" : "Seadistamine",
    "Available for" : "Saadaval",
    "Add storage" : "Lisa andmehoidla",
    "Advanced settings" : "Lisavalikud",
    "Delete" : "Kustuta",
    "Allow users to mount the following external storage" : "Võimalda kasutajatel ühendada järgmist välist andmehoidlat"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/et_EE.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Välised andmehoidlad",
    "Personal" : "Isiklik",
    "System" : "Süsteem",
    "Grant access" : "Anna ligipääs",
    "Error configuring OAuth1" : "OAuth1 seadistamise tõrge",
    "Error configuring OAuth2" : "OAuth2 seadistamise tõrge",
    "Generate keys" : "Loo võtmed",
    "Error generating key pair" : "Viga võtmepaari loomisel",
    "All users. Type to select user or group." : "Kõik kasutajad. Kirjuta, et valida kasutaja või grupp.",
    "(group)" : "(grupp)",
    "Admin defined" : "Admini poolt määratud",
    "Saved" : "Salvestatud",
    "Save" : "Salvesta",
    "Empty response from the server" : "Tühi vastus serverilt",
    "Couldn't get the list of external mount points: {type}" : "Välise ühenduspunkti hankimine ebaõnnestus: {type}",
    "There was an error with message: " : "Sõnumiga tekkis tõrge:",
    "External mount error" : "Välise seostamise tõrge",
    "external-storage" : "väline-salvestuskoht",
    "Username" : "Kasutajanimi",
    "Password" : "Parool",
    "Credentials required" : "Kasutajatunnused on nõutud",
    "Invalid mount point" : "Vigane ühenduspunkt",
    "Objectstore forbidden" : "Objectstore on keelatud",
    "Invalid storage backend \"%s\"" : "Vigane salvestuskoha taustsüsteem \"%s\"",
    "Unsatisfied backend parameters" : "Rahuldamata taustarakenduse parameetrid",
    "Insufficient data: %s" : "Pole piisavalt andmeid: %s",
    "%s" : "%s",
    "Access key" : "Ligipääsuvõti",
    "Secret key" : "Salavõti",
    "Builtin" : "Sisseehitatud",
    "None" : "Pole",
    "OAuth1" : "OAuth1",
    "App key" : "Rakenduse võti",
    "App secret" : "Rakenduse salasõna",
    "OAuth2" : "OAuth2",
    "Client ID" : "Kliendi ID",
    "Client secret" : "Kliendi salasõna",
    "Domain" : "Domeen",
    "API key" : "API võti",
    "RSA public key" : "RSA avalik võti",
    "Public key" : "Avalik võti",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Korv",
    "Hostname" : "Hostinimi",
    "Port" : "Port",
    "Region" : "Piirkond",
    "Enable SSL" : "SSL-i kasutamine",
    "Enable Path Style" : "Luba otsingtee stiilis",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Mujahl olev alamkaust",
    "Secure https://" : "Turvaline https://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Turvaline ftps://",
    "Local" : "Kohalik",
    "Location" : "Asukoht",
    "SFTP" : "SFTP",
    "Root" : "Juur",
    "SFTP with secret key login" : "SFTP koos salajase võtmega logimisega",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Jaga",
    "SMB / CIFS using OC login" : "SMB / CIFS kasutades OC logimist",
    "Username as share" : "Kasutajanimi kui jagamine",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Teenuse nimi",
    "Name" : "Nimi",
    "Storage type" : "Andmehoidla tüüp",
    "Scope" : "Skoop",
    "Enable encryption" : "Luba krüpteerimine",
    "Enable previews" : "Luba eelvaated",
    "Enable sharing" : "Luba jagamine",
    "Check for changes" : "Otsi uuendusi",
    "Never" : "Mitte kunagi",
    "Once every direct access" : "Kord iga otsese pöördumise korral",
    "Folder name" : "Kausta nimi",
    "External storage" : "Väline andmehoidla",
    "Authentication" : "Autentimine",
    "Configuration" : "Seadistamine",
    "Available for" : "Saadaval",
    "Add storage" : "Lisa andmehoidla",
    "Advanced settings" : "Lisavalikud",
    "Delete" : "Kustuta",
    "Allow users to mount the following external storage" : "Võimalda kasutajatel ühendada järgmist välist andmehoidlat",
    "OpenStack" : "OpenStack",
    "No external storage configured" : "Välist salvestuskohta pole seadistatud",
    "You can add external storages in the personal settings" : "Sa võid lisada välise salvestuskoha isiklikes seadetes"
},
"nplurals=2; plural=(n != 1);");
